summaryrefslogtreecommitdiffstats
path: root/ash/shell.cc
diff options
context:
space:
mode:
authoroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-02 20:17:45 +0000
committeroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-02 20:17:45 +0000
commitad0c872627409562edfb75e049ad5184f04d2967 (patch)
treeda354f8d404be002d05eb6012caaf7b6b4a26649 /ash/shell.cc
parent0c8698f841ca346d9a722c81b119762d4bba59dd (diff)
downloadchromium_src-ad0c872627409562edfb75e049ad5184f04d2967.zip
chromium_src-ad0c872627409562edfb75e049ad5184f04d2967.tar.gz
chromium_src-ad0c872627409562edfb75e049ad5184f04d2967.tar.bz2
Switch default WM mode to managed
Don't align window to grid when restoring window. BUG=none TEST=none Review URL: http://codereview.chromium.org/9513004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@124718 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/shell.cc')
-rw-r--r--ash/shell.cc11
1 files changed, 8 insertions, 3 deletions
diff --git a/ash/shell.cc b/ash/shell.cc
index 519c9ee..452f69f 100644
--- a/ash/shell.cc
+++ b/ash/shell.cc
@@ -277,7 +277,7 @@ Shell::Shell(ShellDelegate* delegate)
audio_controller_(NULL),
brightness_controller_(NULL),
shelf_(NULL),
- window_mode_(MODE_OVERLAPPING),
+ window_mode_(MODE_MANAGED),
desktop_background_mode_(BACKGROUND_IMAGE),
root_window_layout_(NULL),
status_widget_(NULL) {
@@ -495,8 +495,8 @@ Shell::WindowMode Shell::ComputeWindowMode(CommandLine* command_line) const {
return MODE_OVERLAPPING;
}
- // Overlapping is the default.
- return Shell::MODE_OVERLAPPING;
+ // Managed is the default.
+ return Shell::MODE_MANAGED;
}
aura::Window* Shell::GetContainer(int container_id) {
@@ -671,4 +671,9 @@ void Shell::ResetLayoutManager(int container_id) {
GetContainer(container_id)->SetLayoutManager(NULL);
}
+void Shell::DisableWorkspaceGridLayout() {
+ if (workspace_controller_.get())
+ workspace_controller_->workspace_manager()->set_grid_size(0);
+}
+
} // namespace ash